// Copyright 2002 Macromedia, Inc. and its licensors.  All Rights Reserved.
//
// Use and/or redistribution of this file, in whole or in part, is subject
// to the Macromedia Sample Files License, which was distributed with this file.
//
//--------------------------------------------------------------------------------
/*
CartModel class

	The CartModel class implements the model and controller mechanism of the
	Model/View/Controller (MVC) architecture.

	The CartModel class handles all communication with the server and holds all cart
	data.  As such, it functions as a Model.

	Via extending the Broadcaster class, the CartModel class also functions as a
	controller for all UI objects that display cart data.

	The CartModel class is meant to be used as a singleton.  In other words, it
	is not instantiated in the program.  All access takes place through the
	single _global.cart instance.

	This file is a pure ActionScript object.

	#include info for this file:

			FLA:				main.fla

			Layer:				Actions : Class Definitions

			Frame:				1

			Library Symbol:		N/A (included on main timeline)

			Library Path:		
*/
//--------------------------------------------------------------------------------

//----------------------------------------------------------------------
//CartModel
//----------------------------------------------------------------------
function CartModel() {
	this.shippingMethods = null;
	this.state_array = null;
	this.country_array = null;
	this.creditCards_array = null;
}

CartModel.prototype = new Broadcaster();

_global.cart = new CartModel();

//----------------------------------------------------------------------
// init
//----------------------------------------------------------------------
CartModel.prototype.init = function(gateway_conn, uri) {
	this.cartService = gateway_conn.getService(uri, this);
}


//----------------------------------------------------------------------
// newCart_Status
//----------------------------------------------------------------------
CartModel.prototype.newCart_Status = function(result) {
	this.broadcast("newCartStatus", result);
}

//----------------------------------------------------------------------
// newCart_result
//----------------------------------------------------------------------
CartModel.prototype.newCart_result = function(result) {
	this.cartOID = result;
	this.broadcast("newCartResult", result);
}

//----------------------------------------------------------------------
// newCart
//----------------------------------------------------------------------
CartModel.prototype.newCart = function() {
	this.cartService.newCart();
}

//----------------------------------------------------------------------
// validateCartOID_Status
//----------------------------------------------------------------------
CartModel.prototype.validateCartOID_Status = function(result) {
	this.broadcast("validateCartOIDStatus", result);
}

//----------------------------------------------------------------------
// validateCartOID_result
//----------------------------------------------------------------------
CartModel.prototype.validateCartOID_result = function(result) {
	this.cartOID = result;
	this.broadcast("validateCartOIDResult", result);
}

//----------------------------------------------------------------------
// validateCartOID
//----------------------------------------------------------------------
CartModel.prototype.validateCartOID = function(cartOID) {
	this.cartService.validateCartOID(cartOID);
}

//----------------------------------------------------------------------
// addCartItem_Status
//----------------------------------------------------------------------
CartModel.prototype.addCartItem_Status = function(result) {
	this.broadcast("itemAddedServerStatus", result);
}

//----------------------------------------------------------------------
// addCartItem_result
//----------------------------------------------------------------------
CartModel.prototype.addCartItem_result = function(result) {
	this.broadcast("itemAddedServer", result);
}

//----------------------------------------------------------------------
// addItemToServer
//
// 	This method invokes the server call.
//----------------------------------------------------------------------
CartModel.prototype.addItemToServer = function(itemOID, qty) {
	this.cartService.addCartItem(this.cartOID, itemOID, qty);
}

//----------------------------------------------------------------------
// addItemLocally
//
// 	This method is just for firing off an event.
//----------------------------------------------------------------------
CartModel.prototype.addItemLocally = function(itemRecord) {
	this.broadcast("itemAddedLocally", itemRecord);
}

//----------------------------------------------------------------------
// getCartTotal
//----------------------------------------------------------------------
CartModel.prototype.getCartTotal = function() {
	this.cartService.getCartTotal(this.cartOID);
}

//----------------------------------------------------------------------
// getCartTotal_status
//----------------------------------------------------------------------
CartModel.prototype.getCartTotal_status = function (result) {
	this.broadcast("totalStatus", result);
}

//----------------------------------------------------------------------
// getCartTotal_result
//----------------------------------------------------------------------
CartModel.prototype.getCartTotal_result = function (result) {
	this.broadcast("total", result);
}

//----------------------------------------------------------------------
// getCartItems_Status
//----------------------------------------------------------------------
CartModel.prototype.getCartItems_Status = function (result) {
	this.broadcast("itemsStatus", result);
}

//----------------------------------------------------------------------
// getCartItems_result
//----------------------------------------------------------------------
CartModel.prototype.getCartItems_result = function (result) {
	this.broadcast("items", result);
}

//----------------------------------------------------------------------
// getCartItems
//----------------------------------------------------------------------
CartModel.prototype.getCartItems = function() {
	this.cartService.getCartItems(this.cartOID);
}

//----------------------------------------------------------------------
// deleteCartItem_Status
//----------------------------------------------------------------------
CartModel.prototype.deleteCartItem_Status = function (result) {
	this.broadcast("itemDeletedStatus", result);
}

//----------------------------------------------------------------------
// deleteCartItem_result
//----------------------------------------------------------------------
CartModel.prototype.deleteCartItem_result = function (result) {
	this.broadcast("itemDeleted", result);
}

//----------------------------------------------------------------------
// deleteCartItem_Status
//----------------------------------------------------------------------
CartModel.prototype.deleteCartItem_Status = function (result) {
	this.broadcast("itemDeletedStatus", result);
}

//----------------------------------------------------------------------
// deleteCartItem_result
//----------------------------------------------------------------------
CartModel.prototype.deleteCartItem_result = function (result) {
	this.broadcast("itemDeleted", result);
}

//----------------------------------------------------------------------
// deleteCartItem
//----------------------------------------------------------------------
CartModel.prototype.deleteCartItem = function(itemOID) {
	this.cartService.deleteCartItem(this.cartOID, itemOID);
}

//----------------------------------------------------------------------
// emptyCart_Status
//----------------------------------------------------------------------
CartModel.prototype.emptyCart_Status = function (result) {
	this.broadcast("emptiedStatus", result);
}

//----------------------------------------------------------------------
// emptyCart_result
//----------------------------------------------------------------------
CartModel.prototype.emptyCart_result = function (result) {
	this.broadcast("emptied", result);
}

//----------------------------------------------------------------------
// emptyCart
//----------------------------------------------------------------------
CartModel.prototype.emptyCart = function() {
	this.cartService.emptyCart(this.cartOID);
}

//----------------------------------------------------------------------
// emptyCartLocally
//
// 	This method is just for firing off an event- it doesn't actually
// 	empty the cart on the server.
//----------------------------------------------------------------------
CartModel.prototype.emptyCartLocally = function() {
	this.broadcast("emptiedLocally");
}

//----------------------------------------------------------------------
// updateCartItem_Status
//----------------------------------------------------------------------
CartModel.prototype.updateCartItem_Status = function (result) {
	this.broadcast("itemUpdatedStatus", result);
}

//----------------------------------------------------------------------
// updateCartItem_result
//----------------------------------------------------------------------
CartModel.prototype.updateCartItem_result = function (result) {
	this.broadcast("itemUpdated", result);
}

//----------------------------------------------------------------------
// updateItem
//----------------------------------------------------------------------
CartModel.prototype.updateItem = function(itemOID, qty) {
	qty = parseInt(qty);
	if(qty != Number.NaN) {
		this.cartService.updateCartItem(this.cartOID, itemOID, qty);
	}
}


//----------------------------------------------------------------------
// applyDiscount
//
// 	Normally we'd roundtrip to the server to figure out what the discount
//	should be.  Here we cheat a bit and provide a discount that's
// 	just the length of the discount string.
//----------------------------------------------------------------------
CartModel.prototype.applyDiscount = function (promoCode) {
	this.broadcast("discountApplied", promoCode.length);
}

//----------------------------------------------------------------------
// updateTotalCost
//
// 	This method is just for firing off an event- it doesn't actually
// 	talk to the server.
//----------------------------------------------------------------------
CartModel.prototype.updateTotalCost = function (amount) {
	this.broadcast("totalCost", amount);
}

//----------------------------------------------------------------------
// setShippingCharge
//
// 	This method is just for firing off an event- it doesn't actually
// 	talk to the server.
//----------------------------------------------------------------------
CartModel.prototype.setShippingCharge = function (amount) {
	this.broadcast("shippingCharge", amount);
}

//----------------------------------------------------------------------
// getStatesAndCountries_Status
//
// 	Unlike most methods, we store local copies for this server result.
//----------------------------------------------------------------------
CartModel.prototype.getStatesAndCountries_Status = function (result) {
	this.state_array = new Array("error");
	this.country_array = new Array("error");
	this.broadcast("statesAndCountriesStatus", result);
}

//----------------------------------------------------------------------
// getStatesAndCountries_result
//
// 	Unlike most methods, we store local copies for this server result.
//----------------------------------------------------------------------
CartModel.prototype.getStatesAndCountries_result = function (result) {
	this.state_array = result.STATES_array;
	this.country_array = result.COUNTRIES_array;
	if(this.state_array == null || this.country_array == null) {
		this.getStatesAndCountries_Status(result);
	}
	else {
		this.broadcast("statesAndCountries", result);
	}
}

//----------------------------------------------------------------------
// getStates
//
// 	This returns the local copy, and doesn't hit the server.
//----------------------------------------------------------------------
CartModel.prototype.getStates = function() {
	return this.state_array;
}

//----------------------------------------------------------------------
// getCountries
//
// 	This returns the local copy, and doesn't hit the server.
//----------------------------------------------------------------------
CartModel.prototype.getCountries = function() {
	return this.country_array;
}

//----------------------------------------------------------------------
// getStatesAndCountriesServer
//
// 	This retrieves the data from the server.
//----------------------------------------------------------------------
CartModel.prototype.getStatesAndCountriesServer = function() {
	this.cartService.getStatesAndCountries();
}

//----------------------------------------------------------------------
// getShippingMethods_Status
//
// 	Unlike most methods, we store local copies for this server result.
//----------------------------------------------------------------------
CartModel.prototype.getShippingMethods_Status = function (result) {
	this.shippingMethods = new RecordSet();
	this.broadcast("shippingMethodsStatus", result);
}

//----------------------------------------------------------------------
// getShippingMethods_result
//
// 	Unlike most methods, we store local copies for this server result.
//----------------------------------------------------------------------
CartModel.prototype.getShippingMethods_result = function (result) {
	this.shippingMethods = result;
	this.broadcast("shippingMethods", result);
}

//----------------------------------------------------------------------
// getShippingMethods
//
// 	This returns the local copy.  It doesn't hit the server.
//----------------------------------------------------------------------
CartModel.prototype.getShippingMethods = function() {
	return this.shippingMethods;
}

//----------------------------------------------------------------------
// getShippingMethodsServer
//
// 	This retrieves the data from the server.
//----------------------------------------------------------------------
CartModel.prototype.getShippingMethodsServer = function() {
	this.cartService.getShippingMethods();
}

//----------------------------------------------------------------------
// getCreditCards_Status
//
// 	Unlike most methods, we store local copies for this server result.
//----------------------------------------------------------------------
CartModel.prototype.getCreditCards_Status = function (result) {
	this.creditCards_array = new Array();
	this.broadcast("creditCardsStatus", result);
}

//----------------------------------------------------------------------
// getCreditCards_result
//
// 	Unlike most methods, we store local copies for this server result.
//----------------------------------------------------------------------
CartModel.prototype.getCreditCards_result = function (result) {
	this.creditCards_array = result;
	this.broadcast("creditCards", result);
}

//----------------------------------------------------------------------
// getCreditCards
//
// 	This returns the local copy.  doesn't hit the server.
//----------------------------------------------------------------------
CartModel.prototype.getCreditCards = function() {
	return this.creditCards_array;
}

//----------------------------------------------------------------------
// getCreditCardsServer
//
// 	This retrieves the data from the server.
//----------------------------------------------------------------------
CartModel.prototype.getCreditCardsServer = function() {
	this.cartService.getCreditCards();
}

//----------------------------------------------------------------------
// setShippingMethod_Status
//----------------------------------------------------------------------
CartModel.prototype.setShippingMethod_Status = function (result) {
	this.broadcast("shippingSetStatus", result);
}

//----------------------------------------------------------------------
// setShippingMethod_result
//----------------------------------------------------------------------
CartModel.prototype.setShippingMethod_result = function (result) {
	this.broadcast("shippingSet", result);
}

//----------------------------------------------------------------------
// setShippingMethod
//----------------------------------------------------------------------
CartModel.prototype.setShippingMethod = function(shippingOID) {
	this.cartService.setShippingMethod(this.cartOID, shippingOID);
}

//----------------------------------------------------------------------
// doCheckout
//----------------------------------------------------------------------
CartModel.prototype.doCheckout = function(cartMC) {
	this.broadcast("doCheckout", cartMC);
}

//----------------------------------------------------------------------
// continueShopping
//
// This is a broadcasting-only method, it doesn't hit the server.
//
// It broadcasts two booleans:
// 	resetToHome- indicates whether we should reset the UI to "home" state.
// 	needNewCart- indicates whether we need a newCart
//----------------------------------------------------------------------
CartModel.prototype.continueShopping = function(resetToHome, needNewCart) {
	var data = new Object();
	data.resetToHome = resetToHome != null ? resetToHome : false;
	data.needNewCart =  needNewCart != null ? needNewCart : false;
	this.broadcast("continueShopping", data);
}

//Authors: Brian Kruse (bkruse), Buck Bito (bbito)
