// Copyright 2002 Macromedia, Inc. and its licensors.  All Rights Reserved.
//
// Use and/or redistribution of this file, in whole or in part, is subject
// to the Macromedia Sample Files License, which was distributed with this file.
//
//--------------------------------------------------------------------------------
/*
CatalogModel class

	The CatalogModel class implements the model and controller mechanism of the
	Model/View/Controller (MVC) architecture.

	The CatalogModel class handles all communication with the server and holds all
	catalog data.  As such, it functions as a Model.

	Via extending the Broadcaster class, the CatalogModel class also functions as a
	Controller for all UI objects that display catalog data.

	The CatalogModel class is meant to be used as a singleton.  In other words, it
	is not instantiated in the program.  All access takes place through the
	single _global.catalog instance.

	This file is a pure ActionScript object.

	#include info for this file:

			FLA:				main.fla

			Layer:				Actions : Class Definitions

			Frame:				1

			Library Symbol:		N/A (included on main timeline)

			Library Path:		
*/
//--------------------------------------------------------------------------------

//----------------------------------------------------------------------
//CatalogModel
//----------------------------------------------------------------------
function CatalogModel() {
	this.locale_str = _global.locale_str != null && _global.locale_str != "" ? 
		_global.locale_str : "en_US";
}

CatalogModel.prototype = new Broadcaster();

_global.catalog = new CatalogModel();

//----------------------------------------------------------------------
// init
//----------------------------------------------------------------------
CatalogModel.prototype.init = function(gateway_conn, uri) {
	this.catService = gateway_conn.getService(uri, this);
}

//----------------------------------------------------------------------
// getCategories
//----------------------------------------------------------------------
CatalogModel.prototype.getCategories = function () {
	this.catService.getCategories(this.locale_str);
}

//----------------------------------------------------------------------
// getCategories_Status
//----------------------------------------------------------------------
CatalogModel.prototype.getCategories_Status = function ( result ) {
	this.broadcast("categoriesStatus", result);
}

//----------------------------------------------------------------------
// getCategories_Result
//----------------------------------------------------------------------
CatalogModel.prototype.getCategories_Result = function ( result ) {
	if(result.getLength() > 0) {
		var data = new Object();
		data.id = result.getItemAt(0)["categoryoid"];
		data.rs = result;
		data.label = "categorydisplayname";
		data.data= "categoryoid";
		this.broadcast("categories", data);
	}
}


//----------------------------------------------------------------------
// searchProducts
//----------------------------------------------------------------------
CatalogModel.prototype.searchProducts = function(str) {
	this.catService.searchProducts(str);
}

//----------------------------------------------------------------------
// searchProducts_Status
//----------------------------------------------------------------------
CatalogModel.prototype.searchProducts_Status = function ( result ) {	
	this.broadcast("productSearchStatus", result);
}

//----------------------------------------------------------------------
// searchProducts_Result
//----------------------------------------------------------------------
CatalogModel.prototype.searchProducts_Result = function ( result ) {	
	this.broadcast("productSearchResult", result);
}

//----------------------------------------------------------------------
// getProducts
//----------------------------------------------------------------------
CatalogModel.prototype.getProducts = function(catoid) {
	this.broadcast("gettingProducts");
	this.catService.getProducts(catoid);
}

//----------------------------------------------------------------------
// getProducts_Status
//----------------------------------------------------------------------
CatalogModel.prototype.getProducts_Status = function ( result ) {	
	this.broadcast("productsStatus", result);
}

//----------------------------------------------------------------------
// getProducts_Result
//----------------------------------------------------------------------
CatalogModel.prototype.getProducts_Result = function ( result ) {	
	if(result.getLength() > 0) {
		var data = new Object();
		data.id = result.getItemAt(0)["CATEGORYOID"];
		data.rs = result;
		data.label = "name";
		data.data= "productoid";
		this.broadcast("products", data);
	}
}

//----------------------------------------------------------------------
// getItem
//----------------------------------------------------------------------
CatalogModel.prototype.getItem = function(itemoid) {
	this.catService.getItem(itemoid);
}

//----------------------------------------------------------------------
// getItem_Status
//----------------------------------------------------------------------
CatalogModel.prototype.getItem_Status = function ( result ) {
	this.broadcast("itemStatus", result);
}

//----------------------------------------------------------------------
// getItem_Result
//----------------------------------------------------------------------
CatalogModel.prototype.getItem_Result = function ( result ) {
	if(result.getLength() > 0) {
		var data = new Object();
		data.id = result.getItemAt(0)["ITEMOID"];
		data.prodoid = result.getItemAt(0)["PRODUCTOID"];
		data.rs = result;
		data.label = "itemname";
		data.data = "itemoid";
		this.broadcast("item", data);
	}
}

//----------------------------------------------------------------------
// getItems
//----------------------------------------------------------------------
CatalogModel.prototype.getItems = function(prodoid) {
	this.catService.getItems(prodoid);
}

//----------------------------------------------------------------------
// getItems_Status
//----------------------------------------------------------------------
CatalogModel.prototype.getItems_Status = function ( result ) {
	this.broadcast("itemsStatus", result);
}

//----------------------------------------------------------------------
// getItems_Result
//----------------------------------------------------------------------
CatalogModel.prototype.getItems_Result = function ( result ) {
	if(result.getLength() > 0) {
		var data = new Object();
		data.id = result.getItemAt(0)["ITEMOID"];
		data.prodoid = result.getItemAt(0)["PRODUCTOID"];
		data.rs = result;
		data.label = "itemname";
		data.data = "itemoid";
		this.broadcast("items", data);
	}
}

//----------------------------------------------------------------------
// browseNewProduct
//----------------------------------------------------------------------
CatalogModel.prototype.browseNewProduct = function (newProduct, catLabel, catName, catColor) {
	var data = { prod : newProduct, catLabel : catLabel , catName : catName, catColor : catColor};
	this.broadcast("browseNewProduct", data);
}

//----------------------------------------------------------------------
// changeSelectedProduct
//----------------------------------------------------------------------
CatalogModel.prototype.changeSelectedProduct = function (categoryOID, productOID) {
	var data = { catOID : categoryOID, prodOID : productOID };
	this.broadcast("changeSelectedProduct", data);
}

//----------------------------------------------------------------------
// categoryChanged
//----------------------------------------------------------------------
CatalogModel.prototype.categoryChanged = function (categoryOID, categoryName) {
	var data = { catOID : categoryOID, catName : categoryName};
	this.broadcast("categoryChanged", data);
}

//----------------------------------------------------------------------
// notifyProductAnimationComplete
//----------------------------------------------------------------------
CatalogModel.prototype.notifyProductAnimationComplete = function (prodRec, label, color) {
	var data = { prodRec : prodRec, label : label, color : color };
	this.broadcast("productAnimationComplete", data);
}
//Authors: Brian Kruse (bkruse), Buck Bito (bbito)
