// Copyright 2002 Macromedia, Inc. and its licensors.  All Rights Reserved.
//
// Use and/or redistribution of this file, in whole or in part, is subject
// to the Macromedia Sample Files License, which was distributed with this file.
//
//--------------------------------------------------------------------------------
/*
                     
UserModel class

	The UserModel class implements the model and controller mechanism of the
	Model/View/Controller (MVC) architecture.

	The UserModel class handles all communication with the server and holds all user
	data.  As such, it functions as a Model.

	Via extending the Broadcaster class, the UserModel class also functions as a
	controller for all UI objects that display user data.

	The UserModel class is meant to be used as a singleton.  In other words, it
	is not instantiated in the program.  All access takes place through the
	single _global.user instance.

	This file is a pure ActionScript object.

	#include info for this file:

			FLA:				main.fla

			Layer:				Actions : Class Definitions

			Frame:				1

			Library Symbol:		N/A (included on main timeline)

			Library Path:		
*/
//--------------------------------------------------------------------------------
//----------------------------------------------------------------------
//UserModel
//----------------------------------------------------------------------
function UserModel() {
}

UserModel.prototype = new Broadcaster();

_global.user = new UserModel();

//----------------------------------------------------------------------
// init
//----------------------------------------------------------------------
UserModel.prototype.init = function (gateway_conn, uri) {
	this.userService = gateway_conn.getService(uri, this);
}

//----------------------------------------------------------------------
// getUserData
//----------------------------------------------------------------------
UserModel.prototype.getUserData = function () {
	return this.userData;
}

//----------------------------------------------------------------------
// addUser_Status
//----------------------------------------------------------------------
UserModel.prototype.addUser_Status = function (result) {
	this.userData = undefined;
	this.broadcast("userAddedStatus", result);
}

//----------------------------------------------------------------------
// addUser_Result
//----------------------------------------------------------------------
UserModel.prototype.addUser_Result = function (result) {
	this.userData = result;
	this.broadcast("userAdded", result);
}

//----------------------------------------------------------------------
// addUser
//----------------------------------------------------------------------
UserModel.prototype.addUser = function (email, pass) {
	this.userService.addUser(email, pass);
}

//----------------------------------------------------------------------
// getUser_Status
//----------------------------------------------------------------------
UserModel.prototype.getUser_Status = function (result) {
	this.userData = undefined;
	this.broadcast("userRetrievedStatus", result);
}

//----------------------------------------------------------------------
// getUser_Result
//----------------------------------------------------------------------
UserModel.prototype.getUser_Result = function (result) {
	this.userData = result;
	this.broadcast("userRetrieved", result);
}

//----------------------------------------------------------------------
// getUser
//----------------------------------------------------------------------
UserModel.prototype.getUser = function (email, pass) {
	this.userService.getUser(email, pass);
}

//----------------------------------------------------------------------
// updateUser_Status
//----------------------------------------------------------------------
UserModel.prototype.updateUser_Status = function (result) {
	this.broadcast("userUpdatedStatus", result);
}

//----------------------------------------------------------------------
// updateUser_Result
//----------------------------------------------------------------------
UserModel.prototype.updateUser_Result = function (result) {
	this.broadcast("userUpdated", result);
}

//----------------------------------------------------------------------
// updateUser
//----------------------------------------------------------------------
UserModel.prototype.updateUser = function () {
	// TRICKY: apparently need to copy the userdata to a new object before
	// sending.
	var userCopy = new Object();
	var fld;
	var useroid = this.userData["useroid"];
	for(fld in this.userData) {
		userCopy[fld] = this.userData[fld];
	}
	userCopy["useroid"] = useroid;
	this.userService.updateUser(userCopy);
	this.userData = userCopy;
}

//Authors: Brian Kruse (bkruse), Buck Bito (bbito)
