// Copyright 2002 Macromedia, Inc. and its licensors.  All Rights Reserved.
//
// Use and/or redistribution of this file, in whole or in part, is subject
// to the Macromedia Sample Files License, which was distributed with this file.
//
#initclip 2
//
//
/*
//
CartUI class

	The CartUI class encapsulates all UI behavior pertaining to the shopping cart.

	This is meant to be used as a singleton: i.e. It's not meant to be
	instantiated directly and all access should go through the _global.cartWidget_mc
	object.

	This file is associated with a library movie clip symbol.

	#include info for this file:

			FLA:				main.fla

			Layer:				Actions : Class

			Frame:				1

			Library Symbol:		cartWidget_mc

			Library Path:		widgetGroup/cartWidget/cartWidget_mc
//
*/
//

//----------------------------------------------------------------------
//CartUI
//----------------------------------------------------------------------
function CartUI() {
	_global.cartWidget_mc = this;
	this.isInCheckout = false;
}

// associate the CartUI class with the authortime cartWidget_mc instance
Object.registerClass("CartSymbol", CartUI);


CartUI.prototype = new MovieClip();

//----------------------------------------------------------------------
// init
//----------------------------------------------------------------------
CartUI.prototype.init = function(tabController, strings, cart, catalog) {
	this.tabController = tabController;
	this.tabCt = TabConstants.prototype.CartUIStartTab;
	this.strings = strings;
	this.cart = cart;
	this.catalog = catalog;
	this.cartSubtotalLabel_txt.text = this.strings.CART_SUBTOTAL_LBL_str;
	this.cartSubtotal_txt.text = _global.formatForCurrency(0);
	this.openContent_mc.productName_txt.text = this.strings.PRODUCT_LBL_str;
	this.openContent_mc.qtyOrdered_txt.text = this.strings.QTY_LBL_str;
	this.openContent_mc.itemPrice_txt.text = this.strings.PRICE_LBL_str;
	this.itemsInCartLabel_txt.text = this.strings.ITEMS_IN_CART_LBL_str;
	this.itemsInCart_txt.text = "0";
	this.openContent_mc.cartCheckout_ib.setChangeHandler("checkoutBtnClick", this);
	_global.sizeAndFormatIconBtn(this.openContent_mc.cartCheckout_ib, strings.CART_CHECKOUT_BTN_LBL_str, _global.formIconBtnFormat, true);
	this.openContent_mc.cartCheckout_ib._visible = false;
	this.openContent_mc.cartRemoveItem_ib.setChangeHandler("removeCartItemServer", this);
	_global.sizeAndFormatIconBtn(this.openContent_mc.cartRemoveItem_ib, strings.CART_REMOVE_BTN_LBL_str, _global.formIconBtnFormat);
	this.openContent_mc.cartRemoveItem_ib._visible = false;
	this.openContent_mc.cart_lb.controller = this;
	this.openContent_mc.cart_lb.tabChildren = true;
	this.openContent_mc.cart_lb.setItemSymbol("FPCCartListItemSymbol");
	this.openContent_mc.cart_lb.measureItmHgt();
	this.openContent_mc.cart_lb.setRowCount(5);
	this.openContent_mc.cart_lb.orig_cart_lb_myonkeydown = this.openContent_mc.cart_lb.myOnKeyDown;
	this.openContent_mc.cart_lb.myOnKeyDown = function() {
		if(Key.isDown(Key.DELETEKEY)) {
			this.controller.removeCartItemServer();
		}
		else {
			this.orig_cart_lb_myonkeydown();
		}
	}
	_global.sizeAndFormatListBox(this.openContent_mc.cart_lb, 5);
	this.openContent_mc.cart_lb.setChangeHandler("cartItemSelectionChanged", this);

	this.tabController.setTab("CartUI", this.headBG_mc, this.tabCt++);
	this.tabController.setTab("CartUI", this.openContent_mc.cart_lb, this.tabCt++);
	this.spinButtonTabIndex = this.tabCt++;
	this.tabController.setTab("CartUI", this.openContent_mc.cartRemoveItem_ib, this.tabCt++);
	this.tabController.setTab("CartUI", this.openContent_mc.cartCheckout_ib, this.tabCt++);
	this.tabController.resetTabs("CartUI"); //Disable tabs on hidden elements for init.
	// Re-enable widget button tab only.
	this.tabController.setTab("CartUI", this.headBG_mc, TabConstants.prototype.CartUIStartTab);

	this.resetTotalCost();
}

//----------------------------------------------------------------------
// startListening
//----------------------------------------------------------------------
CartUI.prototype.startListening = function(broadcaster) {
	broadcaster.addListener(this);
}

//----------------------------------------------------------------------
// listenToBroadcaster
//----------------------------------------------------------------------
CartUI.prototype.listenToBroadcaster = function(event, data) {
	if(event == "items") {
		this.openContent_mc.cart_lb.removeAll();
		this.cart.getCartTotal();
		this.initCartData(data);
	}
	else if(event == "itemAddedServer" || event == "itemDeleted" || event == "itemUpdated") {
		if(event == "itemDeleted") {
			this.removeCartItemLocally(data.itemoid);
		}
		this.updateCartTotal(data);
	}
	else if(event == "itemAddedLocally") {
		this.addItem(data);
		if(!this.isOpen) {
			this.headBG_mc.onPress();
		}
	}
	else if(event == "emptied" || event == "emptiedLocally") {
		this.openContent_mc.cart_lb.removeAll();
		this.cartSubtotal_txt.text = _global.formatForCurrency(0);
		this.itemsInCart_txt.text = "0";
		this.openContent_mc.cartRemoveItem_ib._visible = false;
		this.openContent_mc.cartCheckout_ib._visible = false;
		this.resetTotalCost();
	}
	else if(event == "total") {
		this.updateCartTotal(data);
	}
	else if(event == "discountApplied") {
		this.discount  = data;
		this.updateTotalCost();
	}
	else if(event == "shippingCharge") {
		this.shipCost = data;
		this.updateTotalCost();
	}
	else if(event == "continueShopping") {
		_global.sizeAndFormatIconBtn(this.openContent_mc.cartCheckout_ib, this.strings.CART_CHECKOUT_BTN_LBL_str, _global.formIconBtnFormat, true);
		this.isInCheckout = false;
	}
	else if(event == "doCheckout") {
		_global.sizeAndFormatIconBtn(this.openContent_mc.cartCheckout_ib, this.strings.CART_CONTINUE_BTN_LBL_str, _global.formIconBtnFormat, true);
		this.isInCheckout = true;
	}
}

//----------------------------------------------------------------------
// acceptDrop
//
// 	This is called at the end of the drag and drop operation when an
// 	item from the ItemsUI is dropped on the cart.
//----------------------------------------------------------------------
CartUI.prototype.acceptDrop= function(itm){
	this.addItem(itm);
}


//----------------------------------------------------------------------
// initCartData
//----------------------------------------------------------------------
CartUI.prototype.initCartData = function(data) {
	var l = data.getLength();
	var i;
	for(i = 0; i < l; i++) {
		var itm = data.getItemAt(i);
		if(itm["ITEMQUANTITY"] == undefined || itm["ITEMQUANTITY"] == 0) {
			itm["ITEMQUANTITY"] = 1;
		}
		itm["COLOR"] = "0x"+itm["COLOR"];
		itm["LISTPRICE"] = _global.formatForCurrency(itm["LISTPRICE"]);
		this.openContent_mc.cart_lb.addItem(itm["NAME"], itm);
	}
	this.openContent_mc.cart_lb.setSelectedIndex(0);
	this.openContent_mc.cart_lb.setScrollPosition(0);
}

//----------------------------------------------------------------------
// itemQtySpinBtnChanged
//----------------------------------------------------------------------
CartUI.prototype.itemQtySpinBtnChanged = function(spn) {
	spn.itm["ITEMQUANTITY"] = spn.getValue();
	this.cart.updateItem(spn.itm["ITEMOID"], spn.getValue());
}


//----------------------------------------------------------------------
// addItem
// 
// 	This either adds an item or increments the quantity of an item 
// 	in the cart.
//----------------------------------------------------------------------
CartUI.prototype.addItem = function(itm) {
	if(itm["ITEMQUANTITY"] == undefined ||
		itm["ITEMQUANTITY"] == 0) {
		itm["ITEMQUANTITY"] = 1;
	}
	var duplicate = this.findItemOIDIndex(itm["ITEMOID"]);
	if(duplicate == -1){
		this.cart.addItemToServer(itm["ITEMOID"], 1);
		itm["ITEMQUANTITY"] = 1;
		itm["LISTPRICE"] = _global.formatForCurrency(itm["LISTPRICE"]);
		this.openContent_mc.cart_lb.addItemAt(0, itm["NAME"], itm);
		this.openContent_mc.cart_lb.setSelectedIndex(0);
		this.openContent_mc.cart_lb.setScrollPosition(0);
	}
	else{
		var currItm = this.openContent_mc.cart_lb.getItemAt(duplicate)
		if(currItm.data["ITEMQUANTITY"] < currItm.data["QUANTITY"]) {
			currItm.data["ITEMQUANTITY"]+=1;
			this.cart.updateItem(itm["ITEMOID"], currItm.data["ITEMQUANTITY"]);
			this.openContent_mc.cart_lb.setSelectedIndex(duplicate);
			this.openContent_mc.cart_lb.setScrollPosition(duplicate);
		}
		else {
			this.showQtyExceededError(currItm.data["QUANTITY"],
					"focus", _global.focuser.setFocusee(this.openContent_mc.cart_lb));
		}
	}
}

//----------------------------------------------------------------------
// showQtyExceededError
//----------------------------------------------------------------------
CartUI.prototype.showQtyExceededError = function(qtyAvailable, callback, object)
{
	var msg = _global.appStrings.EXCEEDS_AVAILABLE_MB_MSG_str;
	msg += newline + _global.appStrings.QTY_AVAILABLE_LBL_str + " " + qtyAvailable;
	var title = _global.appStrings.EXCEEDS_AVAILABLE_MB_TTL_str;
	_global.warningBox(title, msg, callback, object);
}

//----------------------------------------------------------------------
// findItemOIDIndex
//
// Utility function to find out if an item's in the cart already.
//----------------------------------------------------------------------
CartUI.prototype.findItemOIDIndex = function(itemOID) {
	var duplicate = -1;
	var j;
	var l = this.openContent_mc.cart_lb.getLength();
	for (j=0; j<l && duplicate == -1; j++){
		var currItm = this.openContent_mc.cart_lb.getItemAt(j);
		if(currItm.data["ITEMOID"] == itemOID){
			duplicate = j;
		}
	}
	return duplicate;
}

//----------------------------------------------------------------------
// removeCartItemServer
//----------------------------------------------------------------------
CartUI.prototype.removeCartItemServer = function() {
	var itm = this.openContent_mc.cart_lb.getSelectedItem();
	if(itm != null) {
		this.cart.deleteCartItem(itm.data["ITEMOID"]);
	}
}

//----------------------------------------------------------------------
// removeCartItemLocally
//----------------------------------------------------------------------
CartUI.prototype.removeCartItemLocally= function(itemOID) {
	var indx = this.findItemOIDIndex(itemOID);
	if(indx != -1) {
		this.openContent_mc.cart_lb.removeItemAt(indx);
		this.openContent_mc.cartRemoveItem_ib._visible = this.openContent_mc.cart_lb.getLength() > 0;
		if(!this.openContent_mc.cartRemoveItem_ib._visible && this.isInCheckout) {
			this.leaveCheckout();
		}
	}
}

//----------------------------------------------------------------------
// updateCartTotal
//----------------------------------------------------------------------
CartUI.prototype.updateCartTotal = function(data) {
	this.itemsInCart_txt.text = data.count;
	this.openContent_mc.cartCheckout_ib._visible = Number(data.count) > 0;
	this.cartSubtotal_txt.text = _global.formatForCurrency(data.total);
	this.subTotal = data.total;
	this.updateTotalCost();
}

//----------------------------------------------------------------------
// cartItemSelectionChanged
//
// As soon as this function is called, it is possible to remove cart 
// items.
//----------------------------------------------------------------------
CartUI.prototype.cartItemSelectionChanged = function() {
	this.openContent_mc.cartRemoveItem_ib._visible = true;
}

//----------------------------------------------------------------------
// checkoutBtnClick
//----------------------------------------------------------------------
CartUI.prototype.checkoutBtnClick = function() {
	if(!this.isInCheckout) {
		this.doCheckout();
	}
	else {
		this.leaveCheckout();
	}
}

//----------------------------------------------------------------------
// doCheckout
//----------------------------------------------------------------------
CartUI.prototype.doCheckout = function() {
	this.cart.doCheckout(this);
}

//----------------------------------------------------------------------
// leaveCheckout
//----------------------------------------------------------------------
CartUI.prototype.leaveCheckout = function() {
	this.cart.continueShopping(false);
}

//----------------------------------------------------------------------
// toggleWidget
//
// Called from WidgetGroup.
//----------------------------------------------------------------------
CartUI.prototype.toggleWidget = function(isOpening) {
	this.isOpen = isOpening;
	if(isOpening){
		this.tabController.restoreTabs("CartUI");
	}
	else{
		this.tabController.resetTabs("CartUI");
		this.tabController.setTab("CartUI", this.headBG_mc, TabConstants.prototype.CartUIStartTab);
	}
}

//----------------------------------------------------------------------
// toggleForCheckout
//
// Moves the cart to or from the checkout mode.
//----------------------------------------------------------------------
CartUI.prototype.toggleForCheckout = function(forCheckout)
{
	this.widgetIconButtonBG_mc._visible = !forCheckout;
	this.headBG_mc.enabled = !forCheckout;
	this.tabController.setTab("CartUI", this.headBG_mc, 
			forCheckout ? undefined : TabConstants.prototype.CartUIStartTab);
	if(forCheckout){
		this.openContent_mc.gotoAndPlay("openForCheckout");
	}
	else{
		this.openContent_mc.gotoAndPlay("closeFromCheckout");
	}
}

//----------------------------------------------------------------------
// initCheckoutView
//
// 	Checkout view is the charge summary.
//----------------------------------------------------------------------
CartUI.prototype.initCheckoutView = function(forCheckout)
{
	// Apply Label Strings
	this.openContent_mc.chargeSummary_mc.head_txt.text = this.strings.CHARGE_SUMMARY_HD_str;
	this.openContent_mc.chargeSummary_mc.hint_txt.text = this.strings.CHARGE_SUMMARY_HINT_str;
	this.openContent_mc.chargeSummary_mc.subtotalLabel_txt.text = this.strings.CHARGE_SUMMARY_SUBTOTAL_LBL_str;
	this.openContent_mc.chargeSummary_mc.discountLabel_txt.text = this.strings.CHARGE_SUMMARY_PROMOTIONS_LBL_str;
	this.openContent_mc.chargeSummary_mc.shippingLabel_txt.text = this.strings.CHARGE_SUMMARY_SHIPPING_LBL_str;
	this.openContent_mc.chargeSummary_mc.taxLabel_txt.text = this.strings.CHARGE_SUMMARY_TAX_LBL_str;
	this.openContent_mc.chargeSummary_mc.grandTotalLabel_txt.text = this.strings.CHARGE_SUMMARY_GRAND_TOTAL_LBL_str;
	this.updateChargeSummaryData();

}

//----------------------------------------------------------------------
// resetTotalCost
//----------------------------------------------------------------------
CartUI.prototype.resetTotalCost = function() {
	this.subTotal = 0;
	if(this.shipCost == null) this.shipCost = 0;
	this.discount = 0;
	this.tax = 0;
	this.total = 0;
	this.updateTotalCost();
}

//----------------------------------------------------------------------
// updateTotalCost
//----------------------------------------------------------------------
CartUI.prototype.updateTotalCost = function() {
	this.total = Number(this.subTotal) - Number(this.discount) + Number(this.shipCost) + Number(this.tax);
	this.cart.updateTotalCost(this.total);
	this.updateChargeSummaryData();
}

//----------------------------------------------------------------------
// updateChargeSummaryData
//----------------------------------------------------------------------
CartUI.prototype.updateChargeSummaryData = function()
{
	this.openContent_mc.chargeSummary_mc.subtotal_txt.text = _global.formatForCurrency(this.subTotal);
	this.openContent_mc.chargeSummary_mc.discount_txt.text = _global.formatForCurrency(this.discount);
	this.openContent_mc.chargeSummary_mc.shipping_txt.text = _global.formatForCurrency(this.shipCost);
	this.openContent_mc.chargeSummary_mc.tax_txt.text  = _global.formatForCurrency(this.tax);
	this.openContent_mc.chargeSummary_mc.grandTotal_txt.text  = _global.formatForCurrency(this.total);
}

#endinitclip
//Authors: Brian Kruse (bkruse), Buck Bito (bbito)
