// Copyright 2002 Macromedia, Inc. and its licensors.  All Rights Reserved.
//
// Use and/or redistribution of this file, in whole or in part, is subject
// to the Macromedia Sample Files License, which was distributed with this file.
//
//
//
/*
//
Main timeline listener

	This file implements the listenToBroadcaster for the main timeline.

	As events are received from Flash Remoting and broadcasted via Broadcasters,
	the main timeline sometimes needs to move the playhead to certain frame.

	This file contains all the logic for doing that.

	This file contains functions only, and is associated with main timeline.

	#include info for this file:

			FLA:				main.fla

			Layer:				Actions : Class Definitions

			Frame:				1

			Library Symbol:		N/A (included on main timeline)

			Library Path:		
//
*/
//
//----------------------------------------------------------------------
// setupListeners
//
// 	The main timeline listens to the ModelClasses, too.
//
//----------------------------------------------------------------------
function setupListeners() {
	// This event is triggered when the application's localized strings are
	// received.  This event is very critical: it's the result of the first
	// remoting call we invoke, and the movie blocks execution until this
	// event is received.  Consequently, we consider any failures related to
	// this event to be catastrophic.
	this.strListenerID = _global.stringResourcesRetriever.addListener(this);

	// These events all cause the main playhead to move
	_global.catalog.addEventListener("browseNewProduct", this);
	_global.catalog.addEventListener("productsStatus", this);
	_global.catalog.addEventListener("categories", this);
	_global.catalog.addEventListener("categoriesStatus", this);
	_global.cart.addEventListener("doCheckout", this);
	_global.cart.addEventListener("continueShopping", this);

	// These events are related to retrieving a persistent cart
	// identifier.
	//
	// Remember the listener IDs for the next three events so we
	// can stop listening once one of the events is received.
	this.newCartStatusListenerID = _global.cart.addEventListener("newCartStatus", this);
	this.newCartListenerID = _global.cart.addEventListener("newCartResult", this);
	this.validateCartOIDResultListenerID = _global.cart.addEventListener("validateCartOIDResult", this);
	_global.cart.addEventListener("validateCartOIDStatus", this);


	// These event listeners are for asynchronously retrieving checkout related
	// strings.  As soon as items are initially retrieved for a cart, checkout
	// related strings are requested and the main timeline listens for when the
	// strings are received.  No action is taken when the strings are received
	// unless the main timeline had begun playing the checkout opening
	// animation before the strings had been received.  In that case, the main
	// timeline will resume playing as soon as the strings are received. 
	_global.cart.addEventListener("items", this);
	_global.cart.addEventListener("shippingMethods", this);
	_global.cart.addEventListener("shippingMethodsStatus", this);
	_global.cart.addEventListener("creditCards", this);
	_global.cart.addEventListener("creditCardsStatus", this);
	_global.cart.addEventListener("statesAndCountries", this);
	_global.cart.addEventListener("statesAndCountriesStatus", this);


}

//----------------------------------------------------------------------
// listenToBroadcaster
//
// 	Typically, the main timeline will be listening so it knows
// 	when to resume playing or so that it knows when to 
// 	move the playhead to a specific location.
//----------------------------------------------------------------------
function listenToBroadcaster(event, data) {
	if(event == "browseNewProduct") {
		if(this.currUIState == "home"){
			gotoAndPlay("firstCategory");
		}
		else{
			gotoAndStop("productSelected");
		}
	}
	else if(event == "productsStatus") {
		itemBrowsing_mc._visible = false;
		_global.categoryUI.reset();
		gotoAndStop("home");
	}
	else if(event == "appStringsStatus") {
		// This is the first remoting call we make.  If it returns a status
		// instead of a result, we're probably unable to recover so we'll 
		// redirect to an error page.
		_global.dieToErrorPage(_global.statusToQS(data));
	}
	else if(event == "appStringsResult") {
		// Stop the remotingTimer_mc and remove it since the first remoting call
		// has successfully completed.  The remotingTimer_mc was set up in
		// initFunctions/mainInit.as and is used to make sure that a Flash Remoting
		// call returns onStatus or onResult within a reasonable amount of time.
		_global.remotingTimer_mc.stop();
		_global.remotingTimer_mc.removeMovieClip();
		_global.appStrings = event == "appStringsResult" ? data : new Object();
		// It's no longer neccessary to listen for the appStringsResult event.
		_global.stringResourcesRetriever.removeListener(this.strListenerID);
		delete this.strListenerID;
		play();
		play();
	}
	else if(event == "validateCartOIDStatus") {
		// create a new user
		_global.cart.newCart();
	}
	else if(event == "newCartStatus" || event == "newCartResult" || event == "validateCartOIDResult") {
		var oid = data;
		if(event == "newCartStatus") {
			oid = -1;
		}
		// We can stop listening now since we've got the cartOID for which we've been
		// listening.
		_global.cart.removeEventListener("newCartResult", this.newCartListenerID);
		_global.cart.removeEventListener("newCartStatus", this.newCartStatusListenerID);
		_global.cart.removeEventListener("newCartStatus", this.validateCartOIDResultListenerID);
		_global.currUserSO.data.cartOID = oid;
		_global.currUserSO.flush();
		play();
	}
	else if(event == "doCheckout") {
		// Change the application tab ordering for checkout mode and move the main playhead
		// to the frame that starts the checkout experience animation.
		_global.tabController.resetTabs("CategoryUI", "ItemsUI", "HistoryUI", "SearchUI");
		_global.tabController.restoreTabs("ProfileUI", "BillingFieldsUI", 
				"ShippingFieldsUI", "ShippingMethodsUI", "PaymentMethodsUI");
		_global.categoryUI.setEnabled(false);
		gotoAndPlay("checkout");
	}
	else if(event == "continueShopping") {
		// Change the application tab ordering to item browsing mode and move the main playhead
		// to the frame that closes the checkout experience animation and restores item browsing.
		_global.tabController.restoreTabs("CategoryUI", "ItemsUI", "HistoryUI", "SearchUI");
		_global.tabController.resetTabs("ProfileUI", "BillingFieldsUI", 
				"ShippingFieldsUI", "ShippingMethodsUI", "PaymentMethodsUI");
		_global.categoryUI.setEnabled(true);
		this.shouldReset = data.resetToHome;
		this.needNewCart = data.needNewCart;
		gotoAndPlay("exitCheckout");
	}
	else if(event == "items") {
		if(!this.cartStringsRequested) {
			this.cartStringsRequested = true;
			// Fire off a request for this data right away.  When received, it will be stored in 
			// the cart object.  It won't be needed until the checkout experience begins, but by 
			// requesting it here, we avoid having to wait for it later when the checkout's opened.
			_global.cart.getStatesAndCountriesServer();
			_global.cart.getShippingMethodsServer();
			_global.cart.getCreditCardsServer();
		}
	}
	else if(event == "categories" || event == "categoriesStatus") {
		this.gotCategories = true;
		if(this.waitingForCategories) {
			this.waitingForCategories = false;
			play();
		}
	}
	else if(event == "statesAndCountries" || event == "statesAndCountriesStatus") {
		if(this.waitingForStatesAndCountries) {
			this.waitingForStatesAndCountries = false;
			play();
		}
	}
	else if(event == "shippingMethods" || event == "shippingMethodsStatus") {
		if(this.waitingForShipping) {
			this.waitingForShipping = false;
			play();
		}
	}
	else if(event == "creditCards" || event == "creditCardsStatus") {
		if(this.waitingForCreditCards) {
			this.waitingForCreditCards = false;
			play();
		}
	}
}

//----------------------------------------------------------------------
//	getNewCart
//
//	   If an order's been placed , the cart OID is no longer valid, thus we
//	   remove it from the Shared Object, stop the main timeline,
//	   and define an object that will restart main timeline when 
//	   a new cartOID has been received.
//----------------------------------------------------------------------
function getNewCart() {
	_global.currUserSO.data.cartOID = undefined;
	_global.currUserSO.flush();
	stop();
	_global.newCartListener = new Object();
	_global.newCartListener.mainTL = this;
	// Define the function that listens for the newCartOID event.
	_global.newCartListener.listenToBroadcaster = function(event, data) {
		// Because this object is only listening for newCartOID events, it's
		// not neccessary to check that the event is a newCartOID event.
		var oid = data;
trace("Got oid");
trace(oid);
		if(event == "newCartStatus") {
			oid = -1;
		}
		_global.currUserSO.data.cartOID = oid;
		_global.currUserSO.flush();
		_global.cart.removeEventListener("newCartResult", this.newCartListenerID);
		_global.cart.removeEventListener("newCartStatus", this.newCartStatusListenerID);
		_global.newCartListener = null;
		this.mainTL.gotoAndPlay(this.mainTL.currUIState);
		delete this;
	}
	// Begin listening for newCartOID related events.
	_global.newCartListener.newCartListenerID = 
		_global.cart.addEventListener("newCartResult", _global.newCartListener);
	_global.newCartListener.newCartStatusListenerID = 
		_global.cart.addEventListener("newCartStatus", _global.newCartListener);
	_global.cart.newCart();
}

//Authors: Brian Kruse (bkruse), Buck Bito (bbito)
